# Clickup Api changelog

## [0.1.18] - 2026-04-09
- Updated connector definition (YAML version 0.1.5)
- Source commit: c5258deb
- SDK version: 0.1.0

## [0.1.17] - 2026-04-09
- Updated connector definition (YAML version 0.1.5)
- Source commit: 6bf360a5
- SDK version: 0.1.0

## [0.1.16] - 2026-04-09
- Updated connector definition (YAML version 0.1.4)
- Source commit: 3cecc817
- SDK version: 0.1.0

## [0.1.15] - 2026-04-08
- Updated connector definition (YAML version 0.1.4)
- Source commit: eeaf9a60
- SDK version: 0.1.0

## [0.1.14] - 2026-04-07
- Updated connector definition (YAML version 0.1.4)
- Source commit: 0bc9ab76
- SDK version: 0.1.0

## [0.1.13] - 2026-04-07
- Updated connector definition (YAML version 0.1.4)
- Source commit: fbc0bacd
- SDK version: 0.1.0

## [0.1.12] - 2026-04-03
- Updated connector definition (YAML version 0.1.4)
- Source commit: 7956e2eb
- SDK version: 0.1.0

## [0.1.11] - 2026-04-01
- Updated connector definition (YAML version 0.1.3)
- Source commit: e4c74933
- SDK version: 0.1.0

## [0.1.10] - 2026-04-01
- Updated connector definition (YAML version 0.1.3)
- Source commit: 513344c6
- SDK version: 0.1.0

## [0.1.9] - 2026-03-27
- Updated connector definition (YAML version 0.1.3)
- Source commit: 09ed4945
- SDK version: 0.1.0

## [0.1.8] - 2026-03-26
- Updated connector definition (YAML version 0.1.2)
- Source commit: 75f38884
- SDK version: 0.1.0

## [0.1.7] - 2026-03-26
- Updated connector definition (YAML version 0.1.2)
- Source commit: 20f00dda
- SDK version: 0.1.0

## [0.1.6] - 2026-03-25
- Updated connector definition (YAML version 0.1.2)
- Source commit: bbb46256
- SDK version: 0.1.0

## [0.1.5] - 2026-03-23
- Updated connector definition (YAML version 0.1.2)
- Source commit: 6ad04bc3
- SDK version: 0.1.0

## [0.1.4] - 2026-03-23
- Updated connector definition (YAML version 0.1.2)
- Source commit: 5718dee3
- SDK version: 0.1.0

## [0.1.3] - 2026-03-12
- Updated connector definition (YAML version 0.1.2)
- Source commit: b541ca65
- SDK version: 0.1.0

## [0.1.2] - 2026-03-11
- Updated connector definition (YAML version 0.1.2)
- Source commit: 44677ecb
- SDK version: 0.1.0

## [0.1.1] - 2026-03-11
- Updated connector definition (YAML version 0.1.2)
- Source commit: 9eba63bb
- SDK version: 0.1.0

## [0.1.0] - 2026-03-11
- Updated connector definition (YAML version 0.1.1)
- Source commit: 595db1f1
- SDK version: 0.1.0
